# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_shared_enums.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_shared_enums.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x17\x64ota_shared_enums.proto\"\xbf\x01\n\x18\x43\x44OTAClientHardwareSpecs\x12\x1a\n\x12logical_processors\x18\x01 \x01(\r\x12\x1d\n\x15\x63pu_cycles_per_second\x18\x02 \x01(\x06\x12\x1d\n\x15total_physical_memory\x18\x03 \x01(\x06\x12\x14\n\x0cis_64_bit_os\x18\x04 \x01(\x08\x12\x1a\n\x12upload_measurement\x18\x05 \x01(\x04\x12\x17\n\x0fprefer_not_host\x18\x06 \x01(\x08\"\xce\x03\n\rCDOTASaveGame\x12\x10\n\x08match_id\x18\x05 \x01(\x04\x12\x11\n\tsave_time\x18\x02 \x01(\r\x12&\n\x07players\x18\x03 \x03(\x0b\x32\x15.CDOTASaveGame.Player\x12\x33\n\x0esave_instances\x18\x04 \x03(\x0b\x32\x1b.CDOTASaveGame.SaveInstance\x1aY\n\x06Player\x12\x33\n\x04team\x18\x01 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04hero\x18\x03 \x01(\t\x1a\xdf\x01\n\x0cSaveInstance\x12\x11\n\tgame_time\x18\x02 \x01(\r\x12\x13\n\x0bteam1_score\x18\x03 \x01(\r\x12\x13\n\x0bteam2_score\x18\x04 \x01(\r\x12\x45\n\x10player_positions\x18\x05 \x03(\x0b\x32+.CDOTASaveGame.SaveInstance.PlayerPositions\x12\x0f\n\x07save_id\x18\x06 \x01(\r\x12\x11\n\tsave_time\x18\x07 \x01(\r\x1a\'\n\x0fPlayerPositions\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02*\xc0\x04\n\rDOTA_GameMode\x12\x16\n\x12\x44OTA_GAMEMODE_NONE\x10\x00\x12\x14\n\x10\x44OTA_GAMEMODE_AP\x10\x01\x12\x14\n\x10\x44OTA_GAMEMODE_CM\x10\x02\x12\x14\n\x10\x44OTA_GAMEMODE_RD\x10\x03\x12\x14\n\x10\x44OTA_GAMEMODE_SD\x10\x04\x12\x14\n\x10\x44OTA_GAMEMODE_AR\x10\x05\x12\x17\n\x13\x44OTA_GAMEMODE_INTRO\x10\x06\x12\x14\n\x10\x44OTA_GAMEMODE_HW\x10\x07\x12\x1c\n\x18\x44OTA_GAMEMODE_REVERSE_CM\x10\x08\x12\x16\n\x12\x44OTA_GAMEMODE_XMAS\x10\t\x12\x1a\n\x16\x44OTA_GAMEMODE_TUTORIAL\x10\n\x12\x14\n\x10\x44OTA_GAMEMODE_MO\x10\x0b\x12\x14\n\x10\x44OTA_GAMEMODE_LP\x10\x0c\x12\x17\n\x13\x44OTA_GAMEMODE_POOL1\x10\r\x12\x14\n\x10\x44OTA_GAMEMODE_FH\x10\x0e\x12\x18\n\x14\x44OTA_GAMEMODE_CUSTOM\x10\x0f\x12\x14\n\x10\x44OTA_GAMEMODE_CD\x10\x10\x12\x14\n\x10\x44OTA_GAMEMODE_BD\x10\x11\x12\x1f\n\x1b\x44OTA_GAMEMODE_ABILITY_DRAFT\x10\x12\x12\x17\n\x13\x44OTA_GAMEMODE_EVENT\x10\x13\x12\x16\n\x12\x44OTA_GAMEMODE_ARDM\x10\x14\x12\x18\n\x14\x44OTA_GAMEMODE_1V1MID\x10\x15\x12\x1b\n\x17\x44OTA_GAMEMODE_ALL_DRAFT\x10\x16*\xbd\x03\n\x0e\x44OTA_GameState\x12\x1d\n\x19\x44OTA_GAMERULES_STATE_INIT\x10\x00\x12\x31\n-DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD\x10\x01\x12\'\n#DOTA_GAMERULES_STATE_HERO_SELECTION\x10\x02\x12&\n\"DOTA_GAMERULES_STATE_STRATEGY_TIME\x10\x03\x12!\n\x1d\x44OTA_GAMERULES_STATE_PRE_GAME\x10\x04\x12)\n%DOTA_GAMERULES_STATE_GAME_IN_PROGRESS\x10\x05\x12\"\n\x1e\x44OTA_GAMERULES_STATE_POST_GAME\x10\x06\x12#\n\x1f\x44OTA_GAMERULES_STATE_DISCONNECT\x10\x07\x12&\n\"DOTA_GAMERULES_STATE_TEAM_SHOWCASE\x10\x08\x12*\n&DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP\x10\t\x12\x1d\n\x19\x44OTA_GAMERULES_STATE_LAST\x10\n*\xb6\x01\n\x0c\x44OTA_GC_TEAM\x12\x1a\n\x16\x44OTA_GC_TEAM_GOOD_GUYS\x10\x00\x12\x19\n\x15\x44OTA_GC_TEAM_BAD_GUYS\x10\x01\x12\x1c\n\x18\x44OTA_GC_TEAM_BROADCASTER\x10\x02\x12\x1a\n\x16\x44OTA_GC_TEAM_SPECTATOR\x10\x03\x12\x1c\n\x18\x44OTA_GC_TEAM_PLAYER_POOL\x10\x04\x12\x17\n\x13\x44OTA_GC_TEAM_NOTEAM\x10\x05*\xe8\x03\n\x06\x45\x45vent\x12\x11\n\rEVENT_ID_NONE\x10\x00\x12\x15\n\x11\x45VENT_ID_DIRETIDE\x10\x01\x12\x1c\n\x18\x45VENT_ID_SPRING_FESTIVAL\x10\x02\x12\x1b\n\x17\x45VENT_ID_FROSTIVUS_2013\x10\x03\x12\x1c\n\x18\x45VENT_ID_COMPENDIUM_2014\x10\x04\x12\x1a\n\x16\x45VENT_ID_NEXON_PC_BANG\x10\x05\x12\x1a\n\x16\x45VENT_ID_PWRD_DAC_2015\x10\x06\x12\x1b\n\x17\x45VENT_ID_NEW_BLOOM_2015\x10\x07\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2015\x10\x08\x12\x1c\n\x18\x45VENT_ID_FALL_MAJOR_2015\x10\t\x12\x16\n\x12\x45VENT_ID_ORACLE_PA\x10\n\x12$\n EVENT_ID_NEW_BLOOM_2015_PREBEAST\x10\x0b\x12\x16\n\x12\x45VENT_ID_FROSTIVUS\x10\x0c\x12\x1e\n\x1a\x45VENT_ID_WINTER_MAJOR_2016\x10\r\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2016\x10\x0e\x12\x1c\n\x18\x45VENT_ID_FALL_MAJOR_2016\x10\x0f\x12\x12\n\x0e\x45VENT_ID_COUNT\x10\x10*\xa8\x02\n\x12\x44OTALeaverStatus_t\x12\x14\n\x10\x44OTA_LEAVER_NONE\x10\x00\x12\x1c\n\x18\x44OTA_LEAVER_DISCONNECTED\x10\x01\x12%\n!DOTA_LEAVER_DISCONNECTED_TOO_LONG\x10\x02\x12\x19\n\x15\x44OTA_LEAVER_ABANDONED\x10\x03\x12\x13\n\x0f\x44OTA_LEAVER_AFK\x10\x04\x12\x1f\n\x1b\x44OTA_LEAVER_NEVER_CONNECTED\x10\x05\x12(\n$DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG\x10\x06\x12\"\n\x1e\x44OTA_LEAVER_FAILED_TO_READY_UP\x10\x07\x12\x18\n\x14\x44OTA_LEAVER_DECLINED\x10\x08*\x9e\x02\n\x15\x44OTAConnectionState_t\x12!\n\x1d\x44OTA_CONNECTION_STATE_UNKNOWN\x10\x00\x12+\n\'DOTA_CONNECTION_STATE_NOT_YET_CONNECTED\x10\x01\x12#\n\x1f\x44OTA_CONNECTION_STATE_CONNECTED\x10\x02\x12&\n\"DOTA_CONNECTION_STATE_DISCONNECTED\x10\x03\x12#\n\x1f\x44OTA_CONNECTION_STATE_ABANDONED\x10\x04\x12!\n\x1d\x44OTA_CONNECTION_STATE_LOADING\x10\x05\x12 \n\x1c\x44OTA_CONNECTION_STATE_FAILED\x10\x06*v\n\rFantasy_Roles\x12\x1a\n\x16\x46\x41NTASY_ROLE_UNDEFINED\x10\x00\x12\x15\n\x11\x46\x41NTASY_ROLE_CORE\x10\x01\x12\x18\n\x14\x46\x41NTASY_ROLE_SUPPORT\x10\x02\x12\x18\n\x14\x46\x41NTASY_ROLE_OFFLANE\x10\x03*\x8a\x01\n\x12\x46\x61ntasy_Team_Slots\x12\x15\n\x11\x46\x41NTASY_SLOT_NONE\x10\x00\x12\x15\n\x11\x46\x41NTASY_SLOT_CORE\x10\x01\x12\x18\n\x14\x46\x41NTASY_SLOT_SUPPORT\x10\x02\x12\x14\n\x10\x46\x41NTASY_SLOT_ANY\x10\x03\x12\x16\n\x12\x46\x41NTASY_SLOT_BENCH\x10\x04*\xdd\x02\n\x16\x46\x61ntasy_Selection_Mode\x12\x1d\n\x19\x46\x41NTASY_SELECTION_INVALID\x10\x00\x12\x1c\n\x18\x46\x41NTASY_SELECTION_LOCKED\x10\x01\x12\x1d\n\x19\x46\x41NTASY_SELECTION_SHUFFLE\x10\x02\x12\x1f\n\x1b\x46\x41NTASY_SELECTION_FREE_PICK\x10\x03\x12\x1b\n\x17\x46\x41NTASY_SELECTION_ENDED\x10\x04\x12 \n\x1c\x46\x41NTASY_SELECTION_PRE_SEASON\x10\x05\x12\x1f\n\x1b\x46\x41NTASY_SELECTION_PRE_DRAFT\x10\x06\x12\x1e\n\x1a\x46\x41NTASY_SELECTION_DRAFTING\x10\x07\x12$\n FANTASY_SELECTION_REGULAR_SEASON\x10\x08\x12 \n\x1c\x46\x41NTASY_SELECTION_CARD_BASED\x10\t*\x82\x05\n\x15\x44OTAChatChannelType_t\x12\x1c\n\x18\x44OTAChannelType_Regional\x10\x00\x12\x1a\n\x16\x44OTAChannelType_Custom\x10\x01\x12\x19\n\x15\x44OTAChannelType_Party\x10\x02\x12\x19\n\x15\x44OTAChannelType_Lobby\x10\x03\x12\x18\n\x14\x44OTAChannelType_Team\x10\x04\x12\x19\n\x15\x44OTAChannelType_Guild\x10\x05\x12\x1b\n\x17\x44OTAChannelType_Fantasy\x10\x06\x12\x1b\n\x17\x44OTAChannelType_Whisper\x10\x07\x12\x1b\n\x17\x44OTAChannelType_Console\x10\x08\x12\x17\n\x13\x44OTAChannelType_Tab\x10\t\x12\x1b\n\x17\x44OTAChannelType_Invalid\x10\n\x12\x1b\n\x17\x44OTAChannelType_GameAll\x10\x0b\x12\x1e\n\x1a\x44OTAChannelType_GameAllies\x10\x0c\x12!\n\x1d\x44OTAChannelType_GameSpectator\x10\r\x12 \n\x1c\x44OTAChannelType_GameCoaching\x10\x0e\x12\x18\n\x14\x44OTAChannelType_Cafe\x10\x0f\x12\x1e\n\x1a\x44OTAChannelType_CustomGame\x10\x10\x12\x1b\n\x17\x44OTAChannelType_Private\x10\x11\x12\x1c\n\x18\x44OTAChannelType_PostGame\x10\x12\x12\x1d\n\x19\x44OTAChannelType_BattleCup\x10\x13\x12!\n\x1d\x44OTAChannelType_HLTVSpectator\x10\x14*\xe3\x01\n\x14\x45ProfileCardSlotType\x12 \n\x1ck_EProfileCardSlotType_Empty\x10\x00\x12\x1f\n\x1bk_EProfileCardSlotType_Stat\x10\x01\x12!\n\x1dk_EProfileCardSlotType_Trophy\x10\x02\x12\x1f\n\x1bk_EProfileCardSlotType_Item\x10\x03\x12\x1f\n\x1bk_EProfileCardSlotType_Hero\x10\x04\x12#\n\x1fk_EProfileCardSlotType_Emoticon\x10\x05*\x95\x01\n\x17\x45MatchGroupServerStatus\x12 \n\x1ck_EMatchGroupServerStatus_OK\x10\x00\x12\x31\n-k_EMatchGroupServerStatus_LimitedAvailability\x10\x01\x12%\n!k_EMatchGroupServerStatus_Offline\x10\x02*O\n\x0c\x44OTA_CM_PICK\x12\x12\n\x0e\x44OTA_CM_RANDOM\x10\x00\x12\x15\n\x11\x44OTA_CM_GOOD_GUYS\x10\x01\x12\x14\n\x10\x44OTA_CM_BAD_GUYS\x10\x02*\x8b\x01\n\x16\x44OTALowPriorityBanType\x12!\n\x1d\x44OTA_LOW_PRIORITY_BAN_ABANDON\x10\x00\x12!\n\x1d\x44OTA_LOW_PRIORITY_BAN_REPORTS\x10\x01\x12+\n\'DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON\x10\x02*}\n\x13\x44OTALobbyReadyState\x12\"\n\x1e\x44OTALobbyReadyState_UNDECLARED\x10\x00\x12 \n\x1c\x44OTALobbyReadyState_ACCEPTED\x10\x01\x12 \n\x1c\x44OTALobbyReadyState_DECLINED\x10\x02*D\n\x0f\x44OTAGameVersion\x12\x18\n\x14GAME_VERSION_CURRENT\x10\x00\x12\x17\n\x13GAME_VERSION_STABLE\x10\x01*\xd2\x03\n\x13\x44OTAJoinLobbyResult\x12\x1c\n\x18\x44OTA_JOIN_RESULT_SUCCESS\x10\x00\x12$\n DOTA_JOIN_RESULT_ALREADY_IN_GAME\x10\x01\x12\"\n\x1e\x44OTA_JOIN_RESULT_INVALID_LOBBY\x10\x02\x12\'\n#DOTA_JOIN_RESULT_INCORRECT_PASSWORD\x10\x03\x12\"\n\x1e\x44OTA_JOIN_RESULT_ACCESS_DENIED\x10\x04\x12\"\n\x1e\x44OTA_JOIN_RESULT_GENERIC_ERROR\x10\x05\x12&\n\"DOTA_JOIN_RESULT_INCORRECT_VERSION\x10\x06\x12\"\n\x1e\x44OTA_JOIN_RESULT_IN_TEAM_PARTY\x10\x07\x12#\n\x1f\x44OTA_JOIN_RESULT_NO_LOBBY_FOUND\x10\x08\x12\x1f\n\x1b\x44OTA_JOIN_RESULT_LOBBY_FULL\x10\t\x12\x32\n.DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION\x10\n\x12\x1c\n\x18\x44OTA_JOIN_RESULT_TIMEOUT\x10\x0b*^\n\x15SelectionPriorityType\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07RADIANT\x10\x01\x12\x08\n\x04\x44IRE\x10\x02\x12\x0e\n\nFIRST_PICK\x10\x03\x12\x0f\n\x0bSECOND_PICK\x10\x04*b\n\rDOTAMatchVote\x12\x19\n\x15\x44OTAMatchVote_INVALID\x10\x00\x12\x1a\n\x16\x44OTAMatchVote_POSITIVE\x10\x01\x12\x1a\n\x16\x44OTAMatchVote_NEGATIVE\x10\x02*\x83\x02\n\x17\x44OTA_LobbyMemberXPBonus\x12#\n\x1f\x44OTA_LobbyMemberXPBonus_DEFAULT\x10\x00\x12*\n&DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER\x10\x01\x12\'\n#DOTA_LobbyMemberXPBonus_SHARE_BONUS\x10\x02\x12!\n\x1d\x44OTA_LobbyMemberXPBonus_PARTY\x10\x03\x12\'\n#DOTA_LobbyMemberXPBonus_RECRUITMENT\x10\x04\x12\"\n\x1e\x44OTA_LobbyMemberXPBonus_PCBANG\x10\x05*x\n\x13\x44OTALobbyVisibility\x12\x1e\n\x1a\x44OTALobbyVisibility_Public\x10\x00\x12\x1f\n\x1b\x44OTALobbyVisibility_Friends\x10\x01\x12 \n\x1c\x44OTALobbyVisibility_Unlisted\x10\x02*\xe7\x02\n\x12\x45\x44OTAPlayerMMRType\x12 \n\x1ck_EDOTAPlayerMMRType_Invalid\x10\x00\x12&\n\"k_EDOTAPlayerMMRType_GeneralHidden\x10\x01\x12#\n\x1fk_EDOTAPlayerMMRType_SoloHidden\x10\x02\x12+\n\'k_EDOTAPlayerMMRType_GeneralCompetitive\x10\x03\x12(\n$k_EDOTAPlayerMMRType_SoloCompetitive\x10\x04\x12.\n*k_EDOTAPlayerMMRType_1v1Competitive_UNUSED\x10\x05\x12.\n*k_EDOTAPlayerMMRType_GeneralSeasonalRanked\x10\x06\x12+\n\'k_EDOTAPlayerMMRType_SoloSeasonalRanked\x10\x07*\x87\x02\n\tMatchType\x12\x15\n\x11MATCH_TYPE_CASUAL\x10\x00\x12\x18\n\x14MATCH_TYPE_COOP_BOTS\x10\x01\x12\x1a\n\x16MATCH_TYPE_TEAM_RANKED\x10\x02\x12 \n\x1cMATCH_TYPE_LEGACY_SOLO_QUEUE\x10\x03\x12\x1a\n\x16MATCH_TYPE_COMPETITIVE\x10\x04\x12\x1e\n\x1aMATCH_TYPE_WEEKEND_TOURNEY\x10\x05\x12\x19\n\x15MATCH_TYPE_CASUAL_1V1\x10\x06\x12\x14\n\x10MATCH_TYPE_EVENT\x10\x07\x12\x1e\n\x1aMATCH_TYPE_SEASONAL_RANKED\x10\x08*\x84\x02\n\x11\x44OTABotDifficulty\x12\x1a\n\x16\x42OT_DIFFICULTY_PASSIVE\x10\x00\x12\x17\n\x13\x42OT_DIFFICULTY_EASY\x10\x01\x12\x19\n\x15\x42OT_DIFFICULTY_MEDIUM\x10\x02\x12\x17\n\x13\x42OT_DIFFICULTY_HARD\x10\x03\x12\x19\n\x15\x42OT_DIFFICULTY_UNFAIR\x10\x04\x12\x1a\n\x16\x42OT_DIFFICULTY_INVALID\x10\x05\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA1\x10\x06\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA2\x10\x07\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA3\x10\x08*\xf3\x01\n\x0eMatchLanguages\x12\x1a\n\x16MATCH_LANGUAGE_INVALID\x10\x00\x12\x1a\n\x16MATCH_LANGUAGE_ENGLISH\x10\x01\x12\x1a\n\x16MATCH_LANGUAGE_RUSSIAN\x10\x02\x12\x1a\n\x16MATCH_LANGUAGE_CHINESE\x10\x03\x12\x19\n\x15MATCH_LANGUAGE_KOREAN\x10\x04\x12\x1a\n\x16MATCH_LANGUAGE_SPANISH\x10\x05\x12\x1d\n\x19MATCH_LANGUAGE_PORTUGUESE\x10\x06\x12\x1b\n\x17MATCH_LANGUAGE_ENGLISH2\x10\x07*\xd8\x02\n\x1a\x45TourneyQueueDeadlineState\x12\'\n#k_ETourneyQueueDeadlineState_Normal\x10\x00\x12\'\n#k_ETourneyQueueDeadlineState_Missed\x10\x01\x12*\n&k_ETourneyQueueDeadlineState_ExpiredOK\x10\x02\x12+\n\'k_ETourneyQueueDeadlineState_SeekingBye\x10\x03\x12\x32\n.k_ETourneyQueueDeadlineState_EligibleForRefund\x10\x04\x12,\n\x1fk_ETourneyQueueDeadlineState_NA\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n)k_ETourneyQueueDeadlineState_ExpiringSoon\x10\x65*\xc7\x02\n\rEMatchOutcome\x12\x1b\n\x17k_EMatchOutcome_Unknown\x10\x00\x12\x1e\n\x1ak_EMatchOutcome_RadVictory\x10\x02\x12\x1f\n\x1bk_EMatchOutcome_DireVictory\x10\x03\x12\x33\n/k_EMatchOutcome_NotScored_PoorNetworkConditions\x10@\x12$\n k_EMatchOutcome_NotScored_Leaver\x10\x41\x12)\n%k_EMatchOutcome_NotScored_ServerCrash\x10\x42\x12*\n&k_EMatchOutcome_NotScored_NeverStarted\x10\x43\x12&\n\"k_EMatchOutcome_NotScored_Canceled\x10\x44\x42\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_DOTA_GAMEMODE = _descriptor.EnumDescriptor(
  name='DOTA_GameMode',
  full_name='DOTA_GameMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_AP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CM', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_RD', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_SD', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_AR', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_INTRO', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_HW', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_REVERSE_CM', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_XMAS', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_TUTORIAL', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_MO', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_LP', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_POOL1', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_FH', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CUSTOM', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CD', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_BD', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ABILITY_DRAFT', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_EVENT', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ARDM', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_1V1MID', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ALL_DRAFT', index=22, number=22,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=687,
  serialized_end=1263,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GAMEMODE)

DOTA_GameMode = enum_type_wrapper.EnumTypeWrapper(_DOTA_GAMEMODE)
_DOTA_GAMESTATE = _descriptor.EnumDescriptor(
  name='DOTA_GameState',
  full_name='DOTA_GameState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_INIT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_HERO_SELECTION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_STRATEGY_TIME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_PRE_GAME', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_GAME_IN_PROGRESS', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_POST_GAME', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_DISCONNECT', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_TEAM_SHOWCASE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_LAST', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1266,
  serialized_end=1711,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GAMESTATE)

DOTA_GameState = enum_type_wrapper.EnumTypeWrapper(_DOTA_GAMESTATE)
_DOTA_GC_TEAM = _descriptor.EnumDescriptor(
  name='DOTA_GC_TEAM',
  full_name='DOTA_GC_TEAM',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_GOOD_GUYS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_BAD_GUYS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_BROADCASTER', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_SPECTATOR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_PLAYER_POOL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_NOTEAM', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1714,
  serialized_end=1896,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GC_TEAM)

DOTA_GC_TEAM = enum_type_wrapper.EnumTypeWrapper(_DOTA_GC_TEAM)
_EEVENT = _descriptor.EnumDescriptor(
  name='EEvent',
  full_name='EEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_DIRETIDE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_SPRING_FESTIVAL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS_2013', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_COMPENDIUM_2014', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEXON_PC_BANG', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_PWRD_DAC_2015', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2015', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2015', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FALL_MAJOR_2015', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_ORACLE_PA', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2015_PREBEAST', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_WINTER_MAJOR_2016', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2016', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FALL_MAJOR_2016', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_COUNT', index=16, number=16,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1899,
  serialized_end=2387,
)
_sym_db.RegisterEnumDescriptor(_EEVENT)

EEvent = enum_type_wrapper.EnumTypeWrapper(_EEVENT)
_DOTALEAVERSTATUS_T = _descriptor.EnumDescriptor(
  name='DOTALeaverStatus_t',
  full_name='DOTALeaverStatus_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DISCONNECTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DISCONNECTED_TOO_LONG', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_ABANDONED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_AFK', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NEVER_CONNECTED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_FAILED_TO_READY_UP', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DECLINED', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2390,
  serialized_end=2686,
)
_sym_db.RegisterEnumDescriptor(_DOTALEAVERSTATUS_T)

DOTALeaverStatus_t = enum_type_wrapper.EnumTypeWrapper(_DOTALEAVERSTATUS_T)
_DOTACONNECTIONSTATE_T = _descriptor.EnumDescriptor(
  name='DOTAConnectionState_t',
  full_name='DOTAConnectionState_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_NOT_YET_CONNECTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_CONNECTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_DISCONNECTED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_ABANDONED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_LOADING', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_FAILED', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2689,
  serialized_end=2975,
)
_sym_db.RegisterEnumDescriptor(_DOTACONNECTIONSTATE_T)

DOTAConnectionState_t = enum_type_wrapper.EnumTypeWrapper(_DOTACONNECTIONSTATE_T)
_FANTASY_ROLES = _descriptor.EnumDescriptor(
  name='Fantasy_Roles',
  full_name='Fantasy_Roles',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_UNDEFINED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_CORE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_SUPPORT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_OFFLANE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2977,
  serialized_end=3095,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_ROLES)

Fantasy_Roles = enum_type_wrapper.EnumTypeWrapper(_FANTASY_ROLES)
_FANTASY_TEAM_SLOTS = _descriptor.EnumDescriptor(
  name='Fantasy_Team_Slots',
  full_name='Fantasy_Team_Slots',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_CORE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_SUPPORT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_ANY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_BENCH', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3098,
  serialized_end=3236,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_TEAM_SLOTS)

Fantasy_Team_Slots = enum_type_wrapper.EnumTypeWrapper(_FANTASY_TEAM_SLOTS)
_FANTASY_SELECTION_MODE = _descriptor.EnumDescriptor(
  name='Fantasy_Selection_Mode',
  full_name='Fantasy_Selection_Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_LOCKED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_SHUFFLE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_FREE_PICK', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_ENDED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_PRE_SEASON', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_PRE_DRAFT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_DRAFTING', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_REGULAR_SEASON', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_CARD_BASED', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3239,
  serialized_end=3588,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_SELECTION_MODE)

Fantasy_Selection_Mode = enum_type_wrapper.EnumTypeWrapper(_FANTASY_SELECTION_MODE)
_DOTACHATCHANNELTYPE_T = _descriptor.EnumDescriptor(
  name='DOTAChatChannelType_t',
  full_name='DOTAChatChannelType_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Regional', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Custom', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Party', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Lobby', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Team', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Guild', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Fantasy', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Whisper', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Console', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Tab', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Invalid', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameAll', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameAllies', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameSpectator', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameCoaching', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Cafe', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_CustomGame', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Private', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_PostGame', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_BattleCup', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_HLTVSpectator', index=20, number=20,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3591,
  serialized_end=4233,
)
_sym_db.RegisterEnumDescriptor(_DOTACHATCHANNELTYPE_T)

DOTAChatChannelType_t = enum_type_wrapper.EnumTypeWrapper(_DOTACHATCHANNELTYPE_T)
_EPROFILECARDSLOTTYPE = _descriptor.EnumDescriptor(
  name='EProfileCardSlotType',
  full_name='EProfileCardSlotType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Empty', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Stat', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Trophy', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Item', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Hero', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Emoticon', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4236,
  serialized_end=4463,
)
_sym_db.RegisterEnumDescriptor(_EPROFILECARDSLOTTYPE)

EProfileCardSlotType = enum_type_wrapper.EnumTypeWrapper(_EPROFILECARDSLOTTYPE)
_EMATCHGROUPSERVERSTATUS = _descriptor.EnumDescriptor(
  name='EMatchGroupServerStatus',
  full_name='EMatchGroupServerStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_OK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_LimitedAvailability', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_Offline', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4466,
  serialized_end=4615,
)
_sym_db.RegisterEnumDescriptor(_EMATCHGROUPSERVERSTATUS)

EMatchGroupServerStatus = enum_type_wrapper.EnumTypeWrapper(_EMATCHGROUPSERVERSTATUS)
_DOTA_CM_PICK = _descriptor.EnumDescriptor(
  name='DOTA_CM_PICK',
  full_name='DOTA_CM_PICK',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_RANDOM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_GOOD_GUYS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_BAD_GUYS', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4617,
  serialized_end=4696,
)
_sym_db.RegisterEnumDescriptor(_DOTA_CM_PICK)

DOTA_CM_PICK = enum_type_wrapper.EnumTypeWrapper(_DOTA_CM_PICK)
_DOTALOWPRIORITYBANTYPE = _descriptor.EnumDescriptor(
  name='DOTALowPriorityBanType',
  full_name='DOTALowPriorityBanType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_ABANDON', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_REPORTS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4699,
  serialized_end=4838,
)
_sym_db.RegisterEnumDescriptor(_DOTALOWPRIORITYBANTYPE)

DOTALowPriorityBanType = enum_type_wrapper.EnumTypeWrapper(_DOTALOWPRIORITYBANTYPE)
_DOTALOBBYREADYSTATE = _descriptor.EnumDescriptor(
  name='DOTALobbyReadyState',
  full_name='DOTALobbyReadyState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_UNDECLARED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_ACCEPTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_DECLINED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4840,
  serialized_end=4965,
)
_sym_db.RegisterEnumDescriptor(_DOTALOBBYREADYSTATE)

DOTALobbyReadyState = enum_type_wrapper.EnumTypeWrapper(_DOTALOBBYREADYSTATE)
_DOTAGAMEVERSION = _descriptor.EnumDescriptor(
  name='DOTAGameVersion',
  full_name='DOTAGameVersion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAME_VERSION_CURRENT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GAME_VERSION_STABLE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4967,
  serialized_end=5035,
)
_sym_db.RegisterEnumDescriptor(_DOTAGAMEVERSION)

DOTAGameVersion = enum_type_wrapper.EnumTypeWrapper(_DOTAGAMEVERSION)
_DOTAJOINLOBBYRESULT = _descriptor.EnumDescriptor(
  name='DOTAJoinLobbyResult',
  full_name='DOTAJoinLobbyResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_ALREADY_IN_GAME', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INVALID_LOBBY', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INCORRECT_PASSWORD', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_ACCESS_DENIED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_GENERIC_ERROR', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INCORRECT_VERSION', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_IN_TEAM_PARTY', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_NO_LOBBY_FOUND', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_LOBBY_FULL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_TIMEOUT', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5038,
  serialized_end=5504,
)
_sym_db.RegisterEnumDescriptor(_DOTAJOINLOBBYRESULT)

DOTAJoinLobbyResult = enum_type_wrapper.EnumTypeWrapper(_DOTAJOINLOBBYRESULT)
_SELECTIONPRIORITYTYPE = _descriptor.EnumDescriptor(
  name='SelectionPriorityType',
  full_name='SelectionPriorityType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIANT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIRE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIRST_PICK', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECOND_PICK', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5506,
  serialized_end=5600,
)
_sym_db.RegisterEnumDescriptor(_SELECTIONPRIORITYTYPE)

SelectionPriorityType = enum_type_wrapper.EnumTypeWrapper(_SELECTIONPRIORITYTYPE)
_DOTAMATCHVOTE = _descriptor.EnumDescriptor(
  name='DOTAMatchVote',
  full_name='DOTAMatchVote',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_POSITIVE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_NEGATIVE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5602,
  serialized_end=5700,
)
_sym_db.RegisterEnumDescriptor(_DOTAMATCHVOTE)

DOTAMatchVote = enum_type_wrapper.EnumTypeWrapper(_DOTAMATCHVOTE)
_DOTA_LOBBYMEMBERXPBONUS = _descriptor.EnumDescriptor(
  name='DOTA_LobbyMemberXPBonus',
  full_name='DOTA_LobbyMemberXPBonus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_DEFAULT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_SHARE_BONUS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_PARTY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_RECRUITMENT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_PCBANG', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5703,
  serialized_end=5962,
)
_sym_db.RegisterEnumDescriptor(_DOTA_LOBBYMEMBERXPBONUS)

DOTA_LobbyMemberXPBonus = enum_type_wrapper.EnumTypeWrapper(_DOTA_LOBBYMEMBERXPBONUS)
_DOTALOBBYVISIBILITY = _descriptor.EnumDescriptor(
  name='DOTALobbyVisibility',
  full_name='DOTALobbyVisibility',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Public', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Friends', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Unlisted', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5964,
  serialized_end=6084,
)
_sym_db.RegisterEnumDescriptor(_DOTALOBBYVISIBILITY)

DOTALobbyVisibility = enum_type_wrapper.EnumTypeWrapper(_DOTALOBBYVISIBILITY)
_EDOTAPLAYERMMRTYPE = _descriptor.EnumDescriptor(
  name='EDOTAPlayerMMRType',
  full_name='EDOTAPlayerMMRType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_Invalid', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralHidden', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_SoloHidden', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralCompetitive', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_SoloCompetitive', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_1v1Competitive_UNUSED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralSeasonalRanked', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_SoloSeasonalRanked', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6087,
  serialized_end=6446,
)
_sym_db.RegisterEnumDescriptor(_EDOTAPLAYERMMRTYPE)

EDOTAPlayerMMRType = enum_type_wrapper.EnumTypeWrapper(_EDOTAPLAYERMMRTYPE)
_MATCHTYPE = _descriptor.EnumDescriptor(
  name='MatchType',
  full_name='MatchType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_CASUAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_COOP_BOTS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_TEAM_RANKED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_LEGACY_SOLO_QUEUE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_COMPETITIVE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_WEEKEND_TOURNEY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_CASUAL_1V1', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_EVENT', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_SEASONAL_RANKED', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6449,
  serialized_end=6712,
)
_sym_db.RegisterEnumDescriptor(_MATCHTYPE)

MatchType = enum_type_wrapper.EnumTypeWrapper(_MATCHTYPE)
_DOTABOTDIFFICULTY = _descriptor.EnumDescriptor(
  name='DOTABotDifficulty',
  full_name='DOTABotDifficulty',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_PASSIVE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EASY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_MEDIUM', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_HARD', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_UNFAIR', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_INVALID', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA1', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA2', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA3', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6715,
  serialized_end=6975,
)
_sym_db.RegisterEnumDescriptor(_DOTABOTDIFFICULTY)

DOTABotDifficulty = enum_type_wrapper.EnumTypeWrapper(_DOTABOTDIFFICULTY)
_MATCHLANGUAGES = _descriptor.EnumDescriptor(
  name='MatchLanguages',
  full_name='MatchLanguages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_ENGLISH', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_RUSSIAN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_CHINESE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_KOREAN', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_SPANISH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_PORTUGUESE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_ENGLISH2', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6978,
  serialized_end=7221,
)
_sym_db.RegisterEnumDescriptor(_MATCHLANGUAGES)

MatchLanguages = enum_type_wrapper.EnumTypeWrapper(_MATCHLANGUAGES)
_ETOURNEYQUEUEDEADLINESTATE = _descriptor.EnumDescriptor(
  name='ETourneyQueueDeadlineState',
  full_name='ETourneyQueueDeadlineState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_Normal', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_Missed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_ExpiredOK', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_SeekingBye', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_EligibleForRefund', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_NA', index=5, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_ExpiringSoon', index=6, number=101,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7224,
  serialized_end=7568,
)
_sym_db.RegisterEnumDescriptor(_ETOURNEYQUEUEDEADLINESTATE)

ETourneyQueueDeadlineState = enum_type_wrapper.EnumTypeWrapper(_ETOURNEYQUEUEDEADLINESTATE)
_EMATCHOUTCOME = _descriptor.EnumDescriptor(
  name='EMatchOutcome',
  full_name='EMatchOutcome',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_RadVictory', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_DireVictory', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_PoorNetworkConditions', index=3, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_Leaver', index=4, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_ServerCrash', index=5, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_NeverStarted', index=6, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_Canceled', index=7, number=68,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7571,
  serialized_end=7898,
)
_sym_db.RegisterEnumDescriptor(_EMATCHOUTCOME)

EMatchOutcome = enum_type_wrapper.EnumTypeWrapper(_EMATCHOUTCOME)
DOTA_GAMEMODE_NONE = 0
DOTA_GAMEMODE_AP = 1
DOTA_GAMEMODE_CM = 2
DOTA_GAMEMODE_RD = 3
DOTA_GAMEMODE_SD = 4
DOTA_GAMEMODE_AR = 5
DOTA_GAMEMODE_INTRO = 6
DOTA_GAMEMODE_HW = 7
DOTA_GAMEMODE_REVERSE_CM = 8
DOTA_GAMEMODE_XMAS = 9
DOTA_GAMEMODE_TUTORIAL = 10
DOTA_GAMEMODE_MO = 11
DOTA_GAMEMODE_LP = 12
DOTA_GAMEMODE_POOL1 = 13
DOTA_GAMEMODE_FH = 14
DOTA_GAMEMODE_CUSTOM = 15
DOTA_GAMEMODE_CD = 16
DOTA_GAMEMODE_BD = 17
DOTA_GAMEMODE_ABILITY_DRAFT = 18
DOTA_GAMEMODE_EVENT = 19
DOTA_GAMEMODE_ARDM = 20
DOTA_GAMEMODE_1V1MID = 21
DOTA_GAMEMODE_ALL_DRAFT = 22
DOTA_GAMERULES_STATE_INIT = 0
DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD = 1
DOTA_GAMERULES_STATE_HERO_SELECTION = 2
DOTA_GAMERULES_STATE_STRATEGY_TIME = 3
DOTA_GAMERULES_STATE_PRE_GAME = 4
DOTA_GAMERULES_STATE_GAME_IN_PROGRESS = 5
DOTA_GAMERULES_STATE_POST_GAME = 6
DOTA_GAMERULES_STATE_DISCONNECT = 7
DOTA_GAMERULES_STATE_TEAM_SHOWCASE = 8
DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP = 9
DOTA_GAMERULES_STATE_LAST = 10
DOTA_GC_TEAM_GOOD_GUYS = 0
DOTA_GC_TEAM_BAD_GUYS = 1
DOTA_GC_TEAM_BROADCASTER = 2
DOTA_GC_TEAM_SPECTATOR = 3
DOTA_GC_TEAM_PLAYER_POOL = 4
DOTA_GC_TEAM_NOTEAM = 5
EVENT_ID_NONE = 0
EVENT_ID_DIRETIDE = 1
EVENT_ID_SPRING_FESTIVAL = 2
EVENT_ID_FROSTIVUS_2013 = 3
EVENT_ID_COMPENDIUM_2014 = 4
EVENT_ID_NEXON_PC_BANG = 5
EVENT_ID_PWRD_DAC_2015 = 6
EVENT_ID_NEW_BLOOM_2015 = 7
EVENT_ID_INTERNATIONAL_2015 = 8
EVENT_ID_FALL_MAJOR_2015 = 9
EVENT_ID_ORACLE_PA = 10
EVENT_ID_NEW_BLOOM_2015_PREBEAST = 11
EVENT_ID_FROSTIVUS = 12
EVENT_ID_WINTER_MAJOR_2016 = 13
EVENT_ID_INTERNATIONAL_2016 = 14
EVENT_ID_FALL_MAJOR_2016 = 15
EVENT_ID_COUNT = 16
DOTA_LEAVER_NONE = 0
DOTA_LEAVER_DISCONNECTED = 1
DOTA_LEAVER_DISCONNECTED_TOO_LONG = 2
DOTA_LEAVER_ABANDONED = 3
DOTA_LEAVER_AFK = 4
DOTA_LEAVER_NEVER_CONNECTED = 5
DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG = 6
DOTA_LEAVER_FAILED_TO_READY_UP = 7
DOTA_LEAVER_DECLINED = 8
DOTA_CONNECTION_STATE_UNKNOWN = 0
DOTA_CONNECTION_STATE_NOT_YET_CONNECTED = 1
DOTA_CONNECTION_STATE_CONNECTED = 2
DOTA_CONNECTION_STATE_DISCONNECTED = 3
DOTA_CONNECTION_STATE_ABANDONED = 4
DOTA_CONNECTION_STATE_LOADING = 5
DOTA_CONNECTION_STATE_FAILED = 6
FANTASY_ROLE_UNDEFINED = 0
FANTASY_ROLE_CORE = 1
FANTASY_ROLE_SUPPORT = 2
FANTASY_ROLE_OFFLANE = 3
FANTASY_SLOT_NONE = 0
FANTASY_SLOT_CORE = 1
FANTASY_SLOT_SUPPORT = 2
FANTASY_SLOT_ANY = 3
FANTASY_SLOT_BENCH = 4
FANTASY_SELECTION_INVALID = 0
FANTASY_SELECTION_LOCKED = 1
FANTASY_SELECTION_SHUFFLE = 2
FANTASY_SELECTION_FREE_PICK = 3
FANTASY_SELECTION_ENDED = 4
FANTASY_SELECTION_PRE_SEASON = 5
FANTASY_SELECTION_PRE_DRAFT = 6
FANTASY_SELECTION_DRAFTING = 7
FANTASY_SELECTION_REGULAR_SEASON = 8
FANTASY_SELECTION_CARD_BASED = 9
DOTAChannelType_Regional = 0
DOTAChannelType_Custom = 1
DOTAChannelType_Party = 2
DOTAChannelType_Lobby = 3
DOTAChannelType_Team = 4
DOTAChannelType_Guild = 5
DOTAChannelType_Fantasy = 6
DOTAChannelType_Whisper = 7
DOTAChannelType_Console = 8
DOTAChannelType_Tab = 9
DOTAChannelType_Invalid = 10
DOTAChannelType_GameAll = 11
DOTAChannelType_GameAllies = 12
DOTAChannelType_GameSpectator = 13
DOTAChannelType_GameCoaching = 14
DOTAChannelType_Cafe = 15
DOTAChannelType_CustomGame = 16
DOTAChannelType_Private = 17
DOTAChannelType_PostGame = 18
DOTAChannelType_BattleCup = 19
DOTAChannelType_HLTVSpectator = 20
k_EProfileCardSlotType_Empty = 0
k_EProfileCardSlotType_Stat = 1
k_EProfileCardSlotType_Trophy = 2
k_EProfileCardSlotType_Item = 3
k_EProfileCardSlotType_Hero = 4
k_EProfileCardSlotType_Emoticon = 5
k_EMatchGroupServerStatus_OK = 0
k_EMatchGroupServerStatus_LimitedAvailability = 1
k_EMatchGroupServerStatus_Offline = 2
DOTA_CM_RANDOM = 0
DOTA_CM_GOOD_GUYS = 1
DOTA_CM_BAD_GUYS = 2
DOTA_LOW_PRIORITY_BAN_ABANDON = 0
DOTA_LOW_PRIORITY_BAN_REPORTS = 1
DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON = 2
DOTALobbyReadyState_UNDECLARED = 0
DOTALobbyReadyState_ACCEPTED = 1
DOTALobbyReadyState_DECLINED = 2
GAME_VERSION_CURRENT = 0
GAME_VERSION_STABLE = 1
DOTA_JOIN_RESULT_SUCCESS = 0
DOTA_JOIN_RESULT_ALREADY_IN_GAME = 1
DOTA_JOIN_RESULT_INVALID_LOBBY = 2
DOTA_JOIN_RESULT_INCORRECT_PASSWORD = 3
DOTA_JOIN_RESULT_ACCESS_DENIED = 4
DOTA_JOIN_RESULT_GENERIC_ERROR = 5
DOTA_JOIN_RESULT_INCORRECT_VERSION = 6
DOTA_JOIN_RESULT_IN_TEAM_PARTY = 7
DOTA_JOIN_RESULT_NO_LOBBY_FOUND = 8
DOTA_JOIN_RESULT_LOBBY_FULL = 9
DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION = 10
DOTA_JOIN_RESULT_TIMEOUT = 11
UNDEFINED = 0
RADIANT = 1
DIRE = 2
FIRST_PICK = 3
SECOND_PICK = 4
DOTAMatchVote_INVALID = 0
DOTAMatchVote_POSITIVE = 1
DOTAMatchVote_NEGATIVE = 2
DOTA_LobbyMemberXPBonus_DEFAULT = 0
DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER = 1
DOTA_LobbyMemberXPBonus_SHARE_BONUS = 2
DOTA_LobbyMemberXPBonus_PARTY = 3
DOTA_LobbyMemberXPBonus_RECRUITMENT = 4
DOTA_LobbyMemberXPBonus_PCBANG = 5
DOTALobbyVisibility_Public = 0
DOTALobbyVisibility_Friends = 1
DOTALobbyVisibility_Unlisted = 2
k_EDOTAPlayerMMRType_Invalid = 0
k_EDOTAPlayerMMRType_GeneralHidden = 1
k_EDOTAPlayerMMRType_SoloHidden = 2
k_EDOTAPlayerMMRType_GeneralCompetitive = 3
k_EDOTAPlayerMMRType_SoloCompetitive = 4
k_EDOTAPlayerMMRType_1v1Competitive_UNUSED = 5
k_EDOTAPlayerMMRType_GeneralSeasonalRanked = 6
k_EDOTAPlayerMMRType_SoloSeasonalRanked = 7
MATCH_TYPE_CASUAL = 0
MATCH_TYPE_COOP_BOTS = 1
MATCH_TYPE_TEAM_RANKED = 2
MATCH_TYPE_LEGACY_SOLO_QUEUE = 3
MATCH_TYPE_COMPETITIVE = 4
MATCH_TYPE_WEEKEND_TOURNEY = 5
MATCH_TYPE_CASUAL_1V1 = 6
MATCH_TYPE_EVENT = 7
MATCH_TYPE_SEASONAL_RANKED = 8
BOT_DIFFICULTY_PASSIVE = 0
BOT_DIFFICULTY_EASY = 1
BOT_DIFFICULTY_MEDIUM = 2
BOT_DIFFICULTY_HARD = 3
BOT_DIFFICULTY_UNFAIR = 4
BOT_DIFFICULTY_INVALID = 5
BOT_DIFFICULTY_EXTRA1 = 6
BOT_DIFFICULTY_EXTRA2 = 7
BOT_DIFFICULTY_EXTRA3 = 8
MATCH_LANGUAGE_INVALID = 0
MATCH_LANGUAGE_ENGLISH = 1
MATCH_LANGUAGE_RUSSIAN = 2
MATCH_LANGUAGE_CHINESE = 3
MATCH_LANGUAGE_KOREAN = 4
MATCH_LANGUAGE_SPANISH = 5
MATCH_LANGUAGE_PORTUGUESE = 6
MATCH_LANGUAGE_ENGLISH2 = 7
k_ETourneyQueueDeadlineState_Normal = 0
k_ETourneyQueueDeadlineState_Missed = 1
k_ETourneyQueueDeadlineState_ExpiredOK = 2
k_ETourneyQueueDeadlineState_SeekingBye = 3
k_ETourneyQueueDeadlineState_EligibleForRefund = 4
k_ETourneyQueueDeadlineState_NA = -1
k_ETourneyQueueDeadlineState_ExpiringSoon = 101
k_EMatchOutcome_Unknown = 0
k_EMatchOutcome_RadVictory = 2
k_EMatchOutcome_DireVictory = 3
k_EMatchOutcome_NotScored_PoorNetworkConditions = 64
k_EMatchOutcome_NotScored_Leaver = 65
k_EMatchOutcome_NotScored_ServerCrash = 66
k_EMatchOutcome_NotScored_NeverStarted = 67
k_EMatchOutcome_NotScored_Canceled = 68



_CDOTACLIENTHARDWARESPECS = _descriptor.Descriptor(
  name='CDOTAClientHardwareSpecs',
  full_name='CDOTAClientHardwareSpecs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logical_processors', full_name='CDOTAClientHardwareSpecs.logical_processors', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_cycles_per_second', full_name='CDOTAClientHardwareSpecs.cpu_cycles_per_second', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_physical_memory', full_name='CDOTAClientHardwareSpecs.total_physical_memory', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_64_bit_os', full_name='CDOTAClientHardwareSpecs.is_64_bit_os', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_measurement', full_name='CDOTAClientHardwareSpecs.upload_measurement', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefer_not_host', full_name='CDOTAClientHardwareSpecs.prefer_not_host', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=219,
)


_CDOTASAVEGAME_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CDOTASaveGame.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CDOTASaveGame.Player.team', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CDOTASaveGame.Player.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero', full_name='CDOTASaveGame.Player.hero', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=458,
)

_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS = _descriptor.Descriptor(
  name='PlayerPositions',
  full_name='CDOTASaveGame.SaveInstance.PlayerPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='CDOTASaveGame.SaveInstance.PlayerPositions.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CDOTASaveGame.SaveInstance.PlayerPositions.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=684,
)

_CDOTASAVEGAME_SAVEINSTANCE = _descriptor.Descriptor(
  name='SaveInstance',
  full_name='CDOTASaveGame.SaveInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CDOTASaveGame.SaveInstance.game_time', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_score', full_name='CDOTASaveGame.SaveInstance.team1_score', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_score', full_name='CDOTASaveGame.SaveInstance.team2_score', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_positions', full_name='CDOTASaveGame.SaveInstance.player_positions', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_id', full_name='CDOTASaveGame.SaveInstance.save_id', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_time', full_name='CDOTASaveGame.SaveInstance.save_time', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=684,
)

_CDOTASAVEGAME = _descriptor.Descriptor(
  name='CDOTASaveGame',
  full_name='CDOTASaveGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CDOTASaveGame.match_id', index=0,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_time', full_name='CDOTASaveGame.save_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CDOTASaveGame.players', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_instances', full_name='CDOTASaveGame.save_instances', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTASAVEGAME_PLAYER, _CDOTASAVEGAME_SAVEINSTANCE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=684,
)

_CDOTASAVEGAME_PLAYER.fields_by_name['team'].enum_type = _DOTA_GC_TEAM
_CDOTASAVEGAME_PLAYER.containing_type = _CDOTASAVEGAME
_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS.containing_type = _CDOTASAVEGAME_SAVEINSTANCE
_CDOTASAVEGAME_SAVEINSTANCE.fields_by_name['player_positions'].message_type = _CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS
_CDOTASAVEGAME_SAVEINSTANCE.containing_type = _CDOTASAVEGAME
_CDOTASAVEGAME.fields_by_name['players'].message_type = _CDOTASAVEGAME_PLAYER
_CDOTASAVEGAME.fields_by_name['save_instances'].message_type = _CDOTASAVEGAME_SAVEINSTANCE
DESCRIPTOR.message_types_by_name['CDOTAClientHardwareSpecs'] = _CDOTACLIENTHARDWARESPECS
DESCRIPTOR.message_types_by_name['CDOTASaveGame'] = _CDOTASAVEGAME
DESCRIPTOR.enum_types_by_name['DOTA_GameMode'] = _DOTA_GAMEMODE
DESCRIPTOR.enum_types_by_name['DOTA_GameState'] = _DOTA_GAMESTATE
DESCRIPTOR.enum_types_by_name['DOTA_GC_TEAM'] = _DOTA_GC_TEAM
DESCRIPTOR.enum_types_by_name['EEvent'] = _EEVENT
DESCRIPTOR.enum_types_by_name['DOTALeaverStatus_t'] = _DOTALEAVERSTATUS_T
DESCRIPTOR.enum_types_by_name['DOTAConnectionState_t'] = _DOTACONNECTIONSTATE_T
DESCRIPTOR.enum_types_by_name['Fantasy_Roles'] = _FANTASY_ROLES
DESCRIPTOR.enum_types_by_name['Fantasy_Team_Slots'] = _FANTASY_TEAM_SLOTS
DESCRIPTOR.enum_types_by_name['Fantasy_Selection_Mode'] = _FANTASY_SELECTION_MODE
DESCRIPTOR.enum_types_by_name['DOTAChatChannelType_t'] = _DOTACHATCHANNELTYPE_T
DESCRIPTOR.enum_types_by_name['EProfileCardSlotType'] = _EPROFILECARDSLOTTYPE
DESCRIPTOR.enum_types_by_name['EMatchGroupServerStatus'] = _EMATCHGROUPSERVERSTATUS
DESCRIPTOR.enum_types_by_name['DOTA_CM_PICK'] = _DOTA_CM_PICK
DESCRIPTOR.enum_types_by_name['DOTALowPriorityBanType'] = _DOTALOWPRIORITYBANTYPE
DESCRIPTOR.enum_types_by_name['DOTALobbyReadyState'] = _DOTALOBBYREADYSTATE
DESCRIPTOR.enum_types_by_name['DOTAGameVersion'] = _DOTAGAMEVERSION
DESCRIPTOR.enum_types_by_name['DOTAJoinLobbyResult'] = _DOTAJOINLOBBYRESULT
DESCRIPTOR.enum_types_by_name['SelectionPriorityType'] = _SELECTIONPRIORITYTYPE
DESCRIPTOR.enum_types_by_name['DOTAMatchVote'] = _DOTAMATCHVOTE
DESCRIPTOR.enum_types_by_name['DOTA_LobbyMemberXPBonus'] = _DOTA_LOBBYMEMBERXPBONUS
DESCRIPTOR.enum_types_by_name['DOTALobbyVisibility'] = _DOTALOBBYVISIBILITY
DESCRIPTOR.enum_types_by_name['EDOTAPlayerMMRType'] = _EDOTAPLAYERMMRTYPE
DESCRIPTOR.enum_types_by_name['MatchType'] = _MATCHTYPE
DESCRIPTOR.enum_types_by_name['DOTABotDifficulty'] = _DOTABOTDIFFICULTY
DESCRIPTOR.enum_types_by_name['MatchLanguages'] = _MATCHLANGUAGES
DESCRIPTOR.enum_types_by_name['ETourneyQueueDeadlineState'] = _ETOURNEYQUEUEDEADLINESTATE
DESCRIPTOR.enum_types_by_name['EMatchOutcome'] = _EMATCHOUTCOME

CDOTAClientHardwareSpecs = _reflection.GeneratedProtocolMessageType('CDOTAClientHardwareSpecs', (_message.Message,), dict(
  DESCRIPTOR = _CDOTACLIENTHARDWARESPECS,
  __module__ = 'dota_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:CDOTAClientHardwareSpecs)
  ))
_sym_db.RegisterMessage(CDOTAClientHardwareSpecs)

CDOTASaveGame = _reflection.GeneratedProtocolMessageType('CDOTASaveGame', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CDOTASAVEGAME_PLAYER,
    __module__ = 'dota_shared_enums_pb2'
    # @@protoc_insertion_point(class_scope:CDOTASaveGame.Player)
    ))
  ,

  SaveInstance = _reflection.GeneratedProtocolMessageType('SaveInstance', (_message.Message,), dict(

    PlayerPositions = _reflection.GeneratedProtocolMessageType('PlayerPositions', (_message.Message,), dict(
      DESCRIPTOR = _CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS,
      __module__ = 'dota_shared_enums_pb2'
      # @@protoc_insertion_point(class_scope:CDOTASaveGame.SaveInstance.PlayerPositions)
      ))
    ,
    DESCRIPTOR = _CDOTASAVEGAME_SAVEINSTANCE,
    __module__ = 'dota_shared_enums_pb2'
    # @@protoc_insertion_point(class_scope:CDOTASaveGame.SaveInstance)
    ))
  ,
  DESCRIPTOR = _CDOTASAVEGAME,
  __module__ = 'dota_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:CDOTASaveGame)
  ))
_sym_db.RegisterMessage(CDOTASaveGame)
_sym_db.RegisterMessage(CDOTASaveGame.Player)
_sym_db.RegisterMessage(CDOTASaveGame.SaveInstance)
_sym_db.RegisterMessage(CDOTASaveGame.SaveInstance.PlayerPositions)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcsystemmsgs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='gcsystemmsgs.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x12gcsystemmsgs.proto*\xae\x16\n\x0c\x45GCSystemMsg\x12\x13\n\x0fk_EGCMsgInvalid\x10\x00\x12\x11\n\rk_EGCMsgMulti\x10\x01\x12\x18\n\x14k_EGCMsgGenericReply\x10\n\x12\x16\n\x12k_EGCMsgSystemBase\x10\x32\x12\x1e\n\x1ak_EGCMsgAchievementAwarded\x10\x33\x12\x16\n\x12k_EGCMsgConCommand\x10\x34\x12\x18\n\x14k_EGCMsgStartPlaying\x10\x35\x12\x17\n\x13k_EGCMsgStopPlaying\x10\x36\x12\x1b\n\x17k_EGCMsgStartGameserver\x10\x37\x12\x1a\n\x16k_EGCMsgStopGameserver\x10\x38\x12\x15\n\x11k_EGCMsgWGRequest\x10\x39\x12\x16\n\x12k_EGCMsgWGResponse\x10:\x12\"\n\x1ek_EGCMsgGetUserGameStatsSchema\x10;\x12*\n&k_EGCMsgGetUserGameStatsSchemaResponse\x10<\x12\"\n\x1ek_EGCMsgGetUserStatsDEPRECATED\x10=\x12 \n\x1ck_EGCMsgGetUserStatsResponse\x10>\x12\x1a\n\x16k_EGCMsgAppInfoUpdated\x10?\x12\x1b\n\x17k_EGCMsgValidateSession\x10@\x12#\n\x1fk_EGCMsgValidateSessionResponse\x10\x41\x12\"\n\x1ek_EGCMsgLookupAccountFromInput\x10\x42\x12\x1b\n\x17k_EGCMsgSendHTTPRequest\x10\x43\x12#\n\x1fk_EGCMsgSendHTTPRequestResponse\x10\x44\x12\x18\n\x14k_EGCMsgPreTestSetup\x10\x45\x12\x1f\n\x1bk_EGCMsgRecordSupportAction\x10\x46\x12(\n$k_EGCMsgGetAccountDetails_DEPRECATED\x10G\x12\"\n\x1ek_EGCMsgReceiveInterAppMessage\x10I\x12\x18\n\x14k_EGCMsgFindAccounts\x10J\x12\x15\n\x11k_EGCMsgPostAlert\x10K\x12\x17\n\x13k_EGCMsgGetLicenses\x10L\x12\x18\n\x14k_EGCMsgGetUserStats\x10M\x12\x17\n\x13k_EGCMsgGetCommands\x10N\x12\x1f\n\x1bk_EGCMsgGetCommandsResponse\x10O\x12\x1a\n\x16k_EGCMsgAddFreeLicense\x10P\x12\"\n\x1ek_EGCMsgAddFreeLicenseResponse\x10Q\x12\x19\n\x15k_EGCMsgGetIPLocation\x10R\x12!\n\x1dk_EGCMsgGetIPLocationResponse\x10S\x12\x1d\n\x19k_EGCMsgSystemStatsSchema\x10T\x12\x1a\n\x16k_EGCMsgGetSystemStats\x10U\x12\"\n\x1ek_EGCMsgGetSystemStatsResponse\x10V\x12\x15\n\x11k_EGCMsgSendEmail\x10W\x12\x1d\n\x19k_EGCMsgSendEmailResponse\x10X\x12\x1c\n\x18k_EGCMsgGetEmailTemplate\x10Y\x12$\n k_EGCMsgGetEmailTemplateResponse\x10Z\x12\x1a\n\x16k_EGCMsgGrantGuestPass\x10[\x12\"\n\x1ek_EGCMsgGrantGuestPassResponse\x10\\\x12\x1d\n\x19k_EGCMsgGetAccountDetails\x10]\x12%\n!k_EGCMsgGetAccountDetailsResponse\x10^\x12\x1b\n\x17k_EGCMsgGetPersonaNames\x10_\x12#\n\x1fk_EGCMsgGetPersonaNamesResponse\x10`\x12\x18\n\x14k_EGCMsgMultiplexMsg\x10\x61\x12$\n k_EGCMsgWebAPIRegisterInterfaces\x10\x65\x12\x1c\n\x18k_EGCMsgWebAPIJobRequest\x10\x66\x12(\n$k_EGCMsgWebAPIJobRequestHttpResponse\x10h\x12+\n\'k_EGCMsgWebAPIJobRequestForwardResponse\x10i\x12\x19\n\x14k_EGCMsgMemCachedGet\x10\xc8\x01\x12!\n\x1ck_EGCMsgMemCachedGetResponse\x10\xc9\x01\x12\x19\n\x14k_EGCMsgMemCachedSet\x10\xca\x01\x12\x1c\n\x17k_EGCMsgMemCachedDelete\x10\xcb\x01\x12\x1b\n\x16k_EGCMsgMemCachedStats\x10\xcc\x01\x12#\n\x1ek_EGCMsgMemCachedStatsResponse\x10\xcd\x01\x12\x15\n\x10k_EGCMsgSQLStats\x10\xd2\x01\x12\x1d\n\x18k_EGCMsgSQLStatsResponse\x10\xd3\x01\x12\x1f\n\x1ak_EGCMsgMasterSetDirectory\x10\xdc\x01\x12\'\n\"k_EGCMsgMasterSetDirectoryResponse\x10\xdd\x01\x12#\n\x1ek_EGCMsgMasterSetWebAPIRouting\x10\xde\x01\x12+\n&k_EGCMsgMasterSetWebAPIRoutingResponse\x10\xdf\x01\x12&\n!k_EGCMsgMasterSetClientMsgRouting\x10\xe0\x01\x12.\n)k_EGCMsgMasterSetClientMsgRoutingResponse\x10\xe1\x01\x12\x17\n\x12k_EGCMsgSetOptions\x10\xe2\x01\x12\x1f\n\x1ak_EGCMsgSetOptionsResponse\x10\xe3\x01\x12\x18\n\x13k_EGCMsgSystemBase2\x10\xf4\x03\x12#\n\x1ek_EGCMsgGetPurchaseTrustStatus\x10\xf5\x03\x12+\n&k_EGCMsgGetPurchaseTrustStatusResponse\x10\xf6\x03\x12\x1a\n\x15k_EGCMsgUpdateSession\x10\xf7\x03\x12%\n k_EGCMsgGCAccountVacStatusChange\x10\xf8\x03\x12\x1c\n\x17k_EGCMsgCheckFriendship\x10\xf9\x03\x12$\n\x1fk_EGCMsgCheckFriendshipResponse\x10\xfa\x03\x12\"\n\x1dk_EGCMsgGetPartnerAccountLink\x10\xfb\x03\x12*\n%k_EGCMsgGetPartnerAccountLinkResponse\x10\xfc\x03\x12)\n$k_EGCMsgVSReportedSuspiciousActivity\x10\xfd\x03\x12\x1f\n\x1ak_EGCMsgDPPartnerMicroTxns\x10\x80\x04\x12\'\n\"k_EGCMsgDPPartnerMicroTxnsResponse\x10\x81\x04\x12\x15\n\x10k_EGCMsgGetIPASN\x10\x82\x04\x12\x1d\n\x18k_EGCMsgGetIPASNResponse\x10\x83\x04\x12\x1e\n\x19k_EGCMsgGetAppFriendsList\x10\x84\x04\x12&\n!k_EGCMsgGetAppFriendsListResponse\x10\x85\x04\x12\"\n\x1dk_EGCMsgVacVerificationChange\x10\x86\x04\x12%\n k_EGCMsgAccountPhoneNumberChange\x10\x87\x04*\xf0\x01\n\x06\x45SOMsg\x12\x13\n\x0fk_ESOMsg_Create\x10\x15\x12\x13\n\x0fk_ESOMsg_Update\x10\x16\x12\x14\n\x10k_ESOMsg_Destroy\x10\x17\x12\x1c\n\x18k_ESOMsg_CacheSubscribed\x10\x18\x12\x1e\n\x1ak_ESOMsg_CacheUnsubscribed\x10\x19\x12\x1b\n\x17k_ESOMsg_UpdateMultiple\x10\x1a\x12%\n!k_ESOMsg_CacheSubscriptionRefresh\x10\x1c\x12$\n k_ESOMsg_CacheSubscribedUpToDate\x10\x1d*\xce\x02\n\x10\x45GCBaseClientMsg\x12\x18\n\x13k_EMsgGCPingRequest\x10\xb9\x17\x12\x19\n\x14k_EMsgGCPingResponse\x10\xba\x17\x12&\n!k_EMsgGCToClientPollConvarRequest\x10\xbb\x17\x12\'\n\"k_EMsgGCToClientPollConvarResponse\x10\xbc\x17\x12\x1a\n\x15k_EMsgGCClientWelcome\x10\xa4\x1f\x12\x1a\n\x15k_EMsgGCServerWelcome\x10\xa5\x1f\x12\x18\n\x13k_EMsgGCClientHello\x10\xa6\x1f\x12\x18\n\x13k_EMsgGCServerHello\x10\xa7\x1f\x12#\n\x1ek_EMsgGCClientConnectionStatus\x10\xa9\x1f\x12#\n\x1ek_EMsgGCServerConnectionStatus\x10\xaa\x1f*\xd7\x04\n\nEGCToGCMsg\x12\x1a\n\x15k_EGCToGCMsgMasterAck\x10\x96\x01\x12\"\n\x1dk_EGCToGCMsgMasterAckResponse\x10\x97\x01\x12\x17\n\x12k_EGCToGCMsgRouted\x10\x98\x01\x12\x1c\n\x17k_EGCToGCMsgRoutedReply\x10\x99\x01\x12#\n\x1ek_EMsgGCUpdateSubGCSessionInfo\x10\x9a\x01\x12$\n\x1fk_EMsgGCRequestSubGCSessionInfo\x10\x9b\x01\x12,\n\'k_EMsgGCRequestSubGCSessionInfoResponse\x10\x9c\x01\x12&\n!k_EGCToGCMsgMasterStartupComplete\x10\x9d\x01\x12!\n\x1ck_EMsgGCToGCSOCacheSubscribe\x10\x9e\x01\x12#\n\x1ek_EMsgGCToGCSOCacheUnsubscribe\x10\x9f\x01\x12#\n\x1ek_EMsgGCToGCLoadSessionSOCache\x10\xa0\x01\x12+\n&k_EMsgGCToGCLoadSessionSOCacheResponse\x10\xa1\x01\x12#\n\x1ek_EMsgGCToGCUpdateSessionStats\x10\xa2\x01\x12 \n\x1bk_EMsgGCToGCUniverseStartup\x10\xa3\x01\x12(\n#k_EMsgGCToGCUniverseStartupResponse\x10\xa4\x01\x12&\n!k_EMsgGCToGCForwardAccountDetails\x10\xa5\x01\x42\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCSYSTEMMSG = _descriptor.EnumDescriptor(
  name='EGCSystemMsg',
  full_name='EGCSystemMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInvalid', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMulti', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGenericReply', index=2, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemBase', index=3, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAchievementAwarded', index=4, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgConCommand', index=5, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStartPlaying', index=6, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStopPlaying', index=7, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStartGameserver', index=8, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStopGameserver', index=9, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWGRequest', index=10, number=57,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWGResponse', index=11, number=58,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserGameStatsSchema', index=12, number=59,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserGameStatsSchemaResponse', index=13, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStatsDEPRECATED', index=14, number=61,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStatsResponse', index=15, number=62,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAppInfoUpdated', index=16, number=63,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgValidateSession', index=17, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgValidateSessionResponse', index=18, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgLookupAccountFromInput', index=19, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendHTTPRequest', index=20, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendHTTPRequestResponse', index=21, number=68,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgPreTestSetup', index=22, number=69,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgRecordSupportAction', index=23, number=70,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetails_DEPRECATED', index=24, number=71,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgReceiveInterAppMessage', index=25, number=73,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgFindAccounts', index=26, number=74,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgPostAlert', index=27, number=75,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetLicenses', index=28, number=76,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStats', index=29, number=77,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetCommands', index=30, number=78,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetCommandsResponse', index=31, number=79,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAddFreeLicense', index=32, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAddFreeLicenseResponse', index=33, number=81,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPLocation', index=34, number=82,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPLocationResponse', index=35, number=83,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemStatsSchema', index=36, number=84,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetSystemStats', index=37, number=85,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetSystemStatsResponse', index=38, number=86,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendEmail', index=39, number=87,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendEmailResponse', index=40, number=88,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetEmailTemplate', index=41, number=89,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetEmailTemplateResponse', index=42, number=90,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGrantGuestPass', index=43, number=91,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGrantGuestPassResponse', index=44, number=92,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetails', index=45, number=93,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetailsResponse', index=46, number=94,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPersonaNames', index=47, number=95,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPersonaNamesResponse', index=48, number=96,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMultiplexMsg', index=49, number=97,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIRegisterInterfaces', index=50, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequest', index=51, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequestHttpResponse', index=52, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequestForwardResponse', index=53, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedGet', index=54, number=200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedGetResponse', index=55, number=201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedSet', index=56, number=202,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedDelete', index=57, number=203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedStats', index=58, number=204,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedStatsResponse', index=59, number=205,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSQLStats', index=60, number=210,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSQLStatsResponse', index=61, number=211,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetDirectory', index=62, number=220,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetDirectoryResponse', index=63, number=221,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetWebAPIRouting', index=64, number=222,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetWebAPIRoutingResponse', index=65, number=223,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetClientMsgRouting', index=66, number=224,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetClientMsgRoutingResponse', index=67, number=225,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSetOptions', index=68, number=226,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSetOptionsResponse', index=69, number=227,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemBase2', index=70, number=500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPurchaseTrustStatus', index=71, number=501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPurchaseTrustStatusResponse', index=72, number=502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUpdateSession', index=73, number=503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGCAccountVacStatusChange', index=74, number=504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgCheckFriendship', index=75, number=505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgCheckFriendshipResponse', index=76, number=506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPartnerAccountLink', index=77, number=507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPartnerAccountLinkResponse', index=78, number=508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgVSReportedSuspiciousActivity', index=79, number=509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgDPPartnerMicroTxns', index=80, number=512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgDPPartnerMicroTxnsResponse', index=81, number=513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPASN', index=82, number=514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPASNResponse', index=83, number=515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAppFriendsList', index=84, number=516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAppFriendsListResponse', index=85, number=517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgVacVerificationChange', index=86, number=518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAccountPhoneNumberChange', index=87, number=519,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=23,
  serialized_end=2885,
)
_sym_db.RegisterEnumDescriptor(_EGCSYSTEMMSG)

EGCSystemMsg = enum_type_wrapper.EnumTypeWrapper(_EGCSYSTEMMSG)
_ESOMSG = _descriptor.EnumDescriptor(
  name='ESOMsg',
  full_name='ESOMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Create', index=0, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Update', index=1, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Destroy', index=2, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscribed', index=3, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheUnsubscribed', index=4, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_UpdateMultiple', index=5, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscriptionRefresh', index=6, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscribedUpToDate', index=7, number=29,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2888,
  serialized_end=3128,
)
_sym_db.RegisterEnumDescriptor(_ESOMSG)

ESOMsg = enum_type_wrapper.EnumTypeWrapper(_ESOMSG)
_EGCBASECLIENTMSG = _descriptor.EnumDescriptor(
  name='EGCBaseClientMsg',
  full_name='EGCBaseClientMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPingRequest', index=0, number=3001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPingResponse', index=1, number=3002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPollConvarRequest', index=2, number=3003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPollConvarResponse', index=3, number=3004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientWelcome', index=4, number=4004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerWelcome', index=5, number=4005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHello', index=6, number=4006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerHello', index=7, number=4007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientConnectionStatus', index=8, number=4009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerConnectionStatus', index=9, number=4010,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3131,
  serialized_end=3465,
)
_sym_db.RegisterEnumDescriptor(_EGCBASECLIENTMSG)

EGCBaseClientMsg = enum_type_wrapper.EnumTypeWrapper(_EGCBASECLIENTMSG)
_EGCTOGCMSG = _descriptor.EnumDescriptor(
  name='EGCToGCMsg',
  full_name='EGCToGCMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterAck', index=0, number=150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterAckResponse', index=1, number=151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgRouted', index=2, number=152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgRoutedReply', index=3, number=153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUpdateSubGCSessionInfo', index=4, number=154,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestSubGCSessionInfo', index=5, number=155,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestSubGCSessionInfoResponse', index=6, number=156,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterStartupComplete', index=7, number=157,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSOCacheSubscribe', index=8, number=158,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSOCacheUnsubscribe', index=9, number=159,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCLoadSessionSOCache', index=10, number=160,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCLoadSessionSOCacheResponse', index=11, number=161,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateSessionStats', index=12, number=162,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUniverseStartup', index=13, number=163,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUniverseStartupResponse', index=14, number=164,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCForwardAccountDetails', index=15, number=165,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3468,
  serialized_end=4067,
)
_sym_db.RegisterEnumDescriptor(_EGCTOGCMSG)

EGCToGCMsg = enum_type_wrapper.EnumTypeWrapper(_EGCTOGCMSG)
k_EGCMsgInvalid = 0
k_EGCMsgMulti = 1
k_EGCMsgGenericReply = 10
k_EGCMsgSystemBase = 50
k_EGCMsgAchievementAwarded = 51
k_EGCMsgConCommand = 52
k_EGCMsgStartPlaying = 53
k_EGCMsgStopPlaying = 54
k_EGCMsgStartGameserver = 55
k_EGCMsgStopGameserver = 56
k_EGCMsgWGRequest = 57
k_EGCMsgWGResponse = 58
k_EGCMsgGetUserGameStatsSchema = 59
k_EGCMsgGetUserGameStatsSchemaResponse = 60
k_EGCMsgGetUserStatsDEPRECATED = 61
k_EGCMsgGetUserStatsResponse = 62
k_EGCMsgAppInfoUpdated = 63
k_EGCMsgValidateSession = 64
k_EGCMsgValidateSessionResponse = 65
k_EGCMsgLookupAccountFromInput = 66
k_EGCMsgSendHTTPRequest = 67
k_EGCMsgSendHTTPRequestResponse = 68
k_EGCMsgPreTestSetup = 69
k_EGCMsgRecordSupportAction = 70
k_EGCMsgGetAccountDetails_DEPRECATED = 71
k_EGCMsgReceiveInterAppMessage = 73
k_EGCMsgFindAccounts = 74
k_EGCMsgPostAlert = 75
k_EGCMsgGetLicenses = 76
k_EGCMsgGetUserStats = 77
k_EGCMsgGetCommands = 78
k_EGCMsgGetCommandsResponse = 79
k_EGCMsgAddFreeLicense = 80
k_EGCMsgAddFreeLicenseResponse = 81
k_EGCMsgGetIPLocation = 82
k_EGCMsgGetIPLocationResponse = 83
k_EGCMsgSystemStatsSchema = 84
k_EGCMsgGetSystemStats = 85
k_EGCMsgGetSystemStatsResponse = 86
k_EGCMsgSendEmail = 87
k_EGCMsgSendEmailResponse = 88
k_EGCMsgGetEmailTemplate = 89
k_EGCMsgGetEmailTemplateResponse = 90
k_EGCMsgGrantGuestPass = 91
k_EGCMsgGrantGuestPassResponse = 92
k_EGCMsgGetAccountDetails = 93
k_EGCMsgGetAccountDetailsResponse = 94
k_EGCMsgGetPersonaNames = 95
k_EGCMsgGetPersonaNamesResponse = 96
k_EGCMsgMultiplexMsg = 97
k_EGCMsgWebAPIRegisterInterfaces = 101
k_EGCMsgWebAPIJobRequest = 102
k_EGCMsgWebAPIJobRequestHttpResponse = 104
k_EGCMsgWebAPIJobRequestForwardResponse = 105
k_EGCMsgMemCachedGet = 200
k_EGCMsgMemCachedGetResponse = 201
k_EGCMsgMemCachedSet = 202
k_EGCMsgMemCachedDelete = 203
k_EGCMsgMemCachedStats = 204
k_EGCMsgMemCachedStatsResponse = 205
k_EGCMsgSQLStats = 210
k_EGCMsgSQLStatsResponse = 211
k_EGCMsgMasterSetDirectory = 220
k_EGCMsgMasterSetDirectoryResponse = 221
k_EGCMsgMasterSetWebAPIRouting = 222
k_EGCMsgMasterSetWebAPIRoutingResponse = 223
k_EGCMsgMasterSetClientMsgRouting = 224
k_EGCMsgMasterSetClientMsgRoutingResponse = 225
k_EGCMsgSetOptions = 226
k_EGCMsgSetOptionsResponse = 227
k_EGCMsgSystemBase2 = 500
k_EGCMsgGetPurchaseTrustStatus = 501
k_EGCMsgGetPurchaseTrustStatusResponse = 502
k_EGCMsgUpdateSession = 503
k_EGCMsgGCAccountVacStatusChange = 504
k_EGCMsgCheckFriendship = 505
k_EGCMsgCheckFriendshipResponse = 506
k_EGCMsgGetPartnerAccountLink = 507
k_EGCMsgGetPartnerAccountLinkResponse = 508
k_EGCMsgVSReportedSuspiciousActivity = 509
k_EGCMsgDPPartnerMicroTxns = 512
k_EGCMsgDPPartnerMicroTxnsResponse = 513
k_EGCMsgGetIPASN = 514
k_EGCMsgGetIPASNResponse = 515
k_EGCMsgGetAppFriendsList = 516
k_EGCMsgGetAppFriendsListResponse = 517
k_EGCMsgVacVerificationChange = 518
k_EGCMsgAccountPhoneNumberChange = 519
k_ESOMsg_Create = 21
k_ESOMsg_Update = 22
k_ESOMsg_Destroy = 23
k_ESOMsg_CacheSubscribed = 24
k_ESOMsg_CacheUnsubscribed = 25
k_ESOMsg_UpdateMultiple = 26
k_ESOMsg_CacheSubscriptionRefresh = 28
k_ESOMsg_CacheSubscribedUpToDate = 29
k_EMsgGCPingRequest = 3001
k_EMsgGCPingResponse = 3002
k_EMsgGCToClientPollConvarRequest = 3003
k_EMsgGCToClientPollConvarResponse = 3004
k_EMsgGCClientWelcome = 4004
k_EMsgGCServerWelcome = 4005
k_EMsgGCClientHello = 4006
k_EMsgGCServerHello = 4007
k_EMsgGCClientConnectionStatus = 4009
k_EMsgGCServerConnectionStatus = 4010
k_EGCToGCMsgMasterAck = 150
k_EGCToGCMsgMasterAckResponse = 151
k_EGCToGCMsgRouted = 152
k_EGCToGCMsgRoutedReply = 153
k_EMsgGCUpdateSubGCSessionInfo = 154
k_EMsgGCRequestSubGCSessionInfo = 155
k_EMsgGCRequestSubGCSessionInfoResponse = 156
k_EGCToGCMsgMasterStartupComplete = 157
k_EMsgGCToGCSOCacheSubscribe = 158
k_EMsgGCToGCSOCacheUnsubscribe = 159
k_EMsgGCToGCLoadSessionSOCache = 160
k_EMsgGCToGCLoadSessionSOCacheResponse = 161
k_EMsgGCToGCUpdateSessionStats = 162
k_EMsgGCToGCUniverseStartup = 163
k_EMsgGCToGCUniverseStartupResponse = 164
k_EMsgGCToGCForwardAccountDetails = 165


DESCRIPTOR.enum_types_by_name['EGCSystemMsg'] = _EGCSYSTEMMSG
DESCRIPTOR.enum_types_by_name['ESOMsg'] = _ESOMSG
DESCRIPTOR.enum_types_by_name['EGCBaseClientMsg'] = _EGCBASECLIENTMSG
DESCRIPTOR.enum_types_by_name['EGCToGCMsg'] = _EGCTOGCMSG


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)



"""
Various utility function for dealing with messages.

"""

from dota2.enums import EGCBaseClientMsg, EDOTAGCMsg, ESOMsg, EGCItemMsg, EGCBaseMsg
from dota2.protobufs import (
    base_gcmessages_pb2,
    gcsdk_gcmessages_pb2,
    dota_gcmessages_common_pb2,
    dota_gcmessages_client_pb2,
    dota_gcmessages_client_chat_pb2,
    dota_gcmessages_client_fantasy_pb2,
    dota_gcmessages_client_guild_pb2,
    dota_gcmessages_client_match_management_pb2,
    dota_gcmessages_client_team_pb2,
    dota_gcmessages_client_tournament_pb2,
    dota_gcmessages_client_watch_pb2,
    econ_gcmessages_pb2,
)


def get_emsg_enum(emsg):
    """
    Attempts to find the Enum for the given :class:`int`

    :param emsg: integer corresponding to a Enum
    :type emsg: :class:`int`
    :return: Enum if found, `emsg` if not
    :rtype: Enum, :class:`int`
    """
    for enum in (EGCBaseClientMsg,
                 EDOTAGCMsg,
                 ESOMsg,
                 EGCBaseMsg,
                 EGCItemMsg,
                 ):
        try:
            return enum(emsg)
        except ValueError:
            pass

    return emsg


def find_proto(emsg):
    """
    Attempts to find the protobuf message for a given Enum

    :param emsg: Enum corrensponding to a protobuf message
    :type emsg: `Enum`
    :return: protobuf message class
    """

    if type(emsg) is int:
        return None

    proto = _proto_map_why_cant_we_name_things_properly.get(emsg, None)

    if proto is not None:
        return proto

    if isinstance(emsg, ESOMsg):
        return getattr(gcsdk_gcmessages_pb2, "CMsgSO%s" % emsg.name, None)

    for module in (base_gcmessages_pb2,
                   gcsdk_gcmessages_pb2,
                   dota_gcmessages_common_pb2,
                   dota_gcmessages_client_pb2,
                   dota_gcmessages_client_chat_pb2,
                   dota_gcmessages_client_fantasy_pb2,
                   dota_gcmessages_client_guild_pb2,
                   dota_gcmessages_client_match_management_pb2,
                   dota_gcmessages_client_team_pb2,
                   dota_gcmessages_client_tournament_pb2,
                   dota_gcmessages_client_watch_pb2,
                   econ_gcmessages_pb2,
                  ):

        proto = getattr(module, emsg.name.replace("EMsg", "CMsg"), None)

        if proto is None:
            proto = getattr(module, emsg.name.replace("EMsgGC", "CMsgDOTA"), None)
        if proto is None:
            proto = getattr(module, emsg.name.replace("EMsgGCToClient", "CMsgDOTA"), None)
        if proto is None:
            proto = getattr(module, emsg.name.replace("EMsgGCToClient", "CMsg"), None)
        if proto is None:
            proto = getattr(module, emsg.name.replace("EMsgGC", "CMsg"), None)
        if proto is None:
            proto = getattr(module, emsg.name.replace("EMsgDOTA", "CMsg"), None)

        if proto is not None:
            break

    return proto


_proto_map_why_cant_we_name_things_properly = {
    EGCBaseClientMsg.EMsgGCClientConnectionStatus: gcsdk_gcmessages_pb2.CMsgConnectionStatus,
    EDOTAGCMsg.EMsgClientToGCGetProfileCardResponse: dota_gcmessages_common_pb2.CMsgDOTAProfileCard,
    EDOTAGCMsg.EMsgClientToGCLatestConductScorecardRequest: dota_gcmessages_client_pb2.CMsgPlayerConductScorecardRequest,
    EDOTAGCMsg.EMsgClientToGCLatestConductScorecard: dota_gcmessages_client_pb2.CMsgPlayerConductScorecard,
    ESOMsg.Create: gcsdk_gcmessages_pb2.CMsgSOSingleObject,
    ESOMsg.Update: gcsdk_gcmessages_pb2.CMsgSOSingleObject,
    ESOMsg.Destroy: gcsdk_gcmessages_pb2.CMsgSOSingleObject,
    ESOMsg.UpdateMultiple: gcsdk_gcmessages_pb2.CMsgSOMultipleObjects,
    EDOTAGCMsg.EMsgClientToGCEventGoalsRequest: dota_gcmessages_client_pb2.CMsgClientToGCGetEventGoals,
    EDOTAGCMsg.EMsgClientToGCEventGoalsResponse: dota_gcmessages_client_pb2.CMsgEventGoals,
    EDOTAGCMsg.EMsgClientToGCSetPartyLeader: dota_gcmessages_client_match_management_pb2.CMsgDOTASetGroupLeader,
    EDOTAGCMsg.EMsgGCOtherJoinedChannel: dota_gcmessages_client_chat_pb2.CMsgDOTAOtherJoinedChatChannel,
    EDOTAGCMsg.EMsgGCOtherLeftChannel: dota_gcmessages_client_chat_pb2.CMsgDOTAOtherLeftChatChannel,
}
